==> figx-0.0.16.tgz: package/es/index.js <==
// Interfaces
export { NodeTypeEnum, ColorFormat, ColorModel } from './interface'; // Node

export { default as isTextNode } from './isTextNode';
export { default as isFrameNode } from './isFrameNode';
export { default as isPageNode } from './isPageNode';
export { default as isVisible } from './isVisible';
export { default as isFillableNode } from './isFillableNode';
export { default as getSelectionNodes } from './getSelectedNodes';
export { default as isLocked } from './isLocked';
export { default as isWithinInstance } from './isWithinInstance'; // Color

export { default as toRgb } from './toRgb';
export { default as toHsl } from './toHsl';
export { default as toHex } from './toHex';
export { default as isSameColor } from './isSameColor';
export { default as getColorContrast } from './getColorContrast'; // Paint

export { default as toSolidPaint } from './toSolidPaint';
export { default as solidPaintToWebRgb } from './solidPaintToWebRgb';
export { default as toImagePaint } from './toImagePaint'; // Storage

export { default as getPluginData } from './getPluginData';
export { default as setPluginData } from './setPluginData'; // Others

export { default as getRandomId } from './getRandomId';
export { default as isEqual } from './isEqual';
export { default as clone } from './clone';
export { default as copyToClipboard } from './copyToClipboard';
export { default as copyToClipboardAsync } from './copyToClipboardAsync';
export { default as getDropPosition } from './getDropPosition';

==> figx-0.1.3.tgz: package/es/index.js <==
// Interfaces
export { NodeTypeEnum, ColorFormat, ColorModel } from './interface'; // Node

export { default as isTextNode } from './isTextNode';
export { default as isFrameNode } from './isFrameNode';
export { default as isEllipseNode } from './isEllipseNode';
export { default as isPageNode } from './isPageNode';
export { default as isComponentNode } from './isComponentNode';
export { default as isInstanceNode } from './isInstanceNode';
export { default as isVisible } from './isVisible';
export { default as isFillableNode } from './isFillableNode';
export { default as getSelectionNodes } from './getSelectedNodes';
export { default as isLocked } from './isLocked';
export { default as isWithinInstance } from './isWithinInstance';
export { default as getComponentProps } from './getComponentProps'; // Color

export { default as toRgb } from './toRgb';
export { default as toHsl } from './toHsl';
export { default as toHex } from './toHex';
export { default as isSameColor } from './isSameColor';
export { default as isValidColor } from './isValidColor';
export { default as getColorContrast } from './getColorContrast'; // Paint

export { default as toSolidPaint } from './toSolidPaint';
export { default as solidPaintToWebRgb } from './solidPaintToWebRgb';
export { default as toImagePaint } from './toImagePaint';
export { default as isImagePaint } from './isImagePaint';
export { default as isGradientPaint } from './isGradientPaint'; // Storage

export { default as getPluginData } from './getPluginData';
export { default as setPluginData } from './setPluginData'; // Others

export { default as getRandomId } from './getRandomId';
export { default as isEqual } from './isEqual';
export { default as clone } from './clone';
export { default as copyToClipboard } from './copyToClipboard';
export { default as copyToClipboardAsync } from './copyToClipboardAsync';
export { default as getDropPosition } from './getDropPosition';
